"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
var AuthModule_1;
const common_1 = require("@nestjs/common");
const user_entity_1 = require("./entities/user.entity");
const typeorm_1 = require("@nestjs/typeorm");
const services_1 = require("./services");
const auth_controller_1 = require("./auth.controller");
const jwt_1 = require("@nestjs/jwt");
const user_repository_1 = require("./repositories/user.repository");
const jwt_strategy_1 = require("./services/jwt.strategy");
const passport_1 = require("@nestjs/passport");
const core_1 = require("@nestjs/core");
const auth_guard_1 = require("./auth.guard");
const auth_options_constant_1 = require("./auth-options.constant");
let AuthModule = AuthModule_1 = class AuthModule {
    static forRoot(options) {
        return {
            module: AuthModule_1,
            imports: [
                passport_1.PassportModule.register({
                    defaultStrategy: 'jwt'
                }),
                typeorm_1.TypeOrmModule.forFeature([user_entity_1.User, user_repository_1.UserRepository]),
                jwt_1.JwtModule.register({
                    secret: options.secret,
                    signOptions: {
                        expiresIn: options.expiresIn
                    }
                }),
            ],
            providers: [
                services_1.AuthService,
                services_1.UserService,
                jwt_strategy_1.JwtStrategy,
                {
                    provide: core_1.APP_GUARD,
                    useFactory: () => new auth_guard_1.AuthGuard(new core_1.Reflector()),
                    inject: [core_1.Reflector]
                },
                {
                    provide: auth_options_constant_1.AUTH_OPTIONS,
                    useValue: options
                }
            ],
            controllers: [auth_controller_1.AuthController],
            exports: [jwt_strategy_1.JwtStrategy, passport_1.PassportModule]
        };
    }
};
AuthModule = AuthModule_1 = tslib_1.__decorate([
    common_1.Global(),
    common_1.Module({})
], AuthModule);
exports.AuthModule = AuthModule;
//# sourceMappingURL=auth.module.js.map