"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const typeorm_1 = require("typeorm");
const entities_1 = require("../entities");
const common_1 = require("@nestjs/common");
const bcrypt = require("bcrypt");
let UserRepository = class UserRepository extends typeorm_1.Repository {
    register(authCredentials) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { email, password } = authCredentials;
            const exists = yield this.findOne({ email });
            if (exists) {
                throw new common_1.ConflictException(`Email ${email} already exists`);
            }
            const user = new entities_1.User();
            user.email = email;
            user.password = password;
            // generate unique salt per user
            user.salt = yield bcrypt.genSalt();
            user.password = yield this.hashPassword(user.password, user.salt);
            yield user.save();
        });
    }
    validatePassword(authCredentials) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { email, password } = authCredentials;
            const user = yield this.findOne({ email });
            if (user && (yield user.validatePassword(password))) {
                return user.email;
            }
            else {
                return null;
            }
        });
    }
    hashPassword(password, salt) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return bcrypt.hash(password, salt);
        });
    }
};
UserRepository = tslib_1.__decorate([
    typeorm_1.EntityRepository(entities_1.User)
], UserRepository);
exports.UserRepository = UserRepository;
//# sourceMappingURL=user.repository.js.map